@@ -1,8 +1,9 @@
 import gzip
 import os
 
+import attr
+
 from ddtrace.profiling.exporter import pprof
-from ddtrace.vendor import attr
 
 
 @attr.s
@@ -25,5 +26,5 @@ class PprofFileExporter(pprof.PprofExporter):
         """
         profile = super(PprofFileExporter, self).export(events, start_time_ns, end_time_ns)
         with gzip.open(self.prefix + (".%d.%d" % (os.getpid(), self._increment)), "wb") as f:
-            f.write(profile.SerializeToString())  # type: ignore[attr-defined]
+            f.write(profile.SerializeToString())
         self._increment += 1
